import pandas as pd    
import datetime as dt  
from binance.client import Client

def binance_price(api_key, api_secret, symbol, interval, startdate, enddate):
    """
	Gets historical price data using Binance API. 

    Parameters
    ----------
    api_key : string
    	Your personal api key provided by Binance. 
        
    api_secret : string
    	Your personal api secret key provided by Binance.
        
    symbol : string
    	Ticker of traded asset. Example 'BTCUSDT' or 'ETHBNB'
        
    interval : string
    	Choose from '1d', '1w', '1h', '5m'
        
    startdate : string
        Starting date of historical data. Example '01-01-2022'.

    enddate : string
        Ending day of historical data. Example '30-01-2022'.

    Returns
    -------
	pandas.DataFrame 

    """

	api_key = api_key
	api_secret = api_secret
	client = Client(api_key, api_secret)
	data = client.get_historical_klines(symbol, interval, startdate, enddate)


	df = pd.DataFrame(data)
	df.columns = ['Open time', 'Open', 'High', 'Low', 'Close', 'Volume',
				 'Close time', 'Qutoe asset volume', 'Number of trades', 
				 'Taker buy base asset volume', 'Taker buy quote asset volume', 'Ignore']
	df.index = [dt.datetime.fromtimestamp(x/1000.0) for x in df['Open time']]
	df = df[['Close']]
	df['Close'] = df['Close'].astype(float)
	return df

